'use strict';
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.LoadEnvironmentVariables = void 0;
const dotenv_1 = __importDefault(require("dotenv"));
const fs_1 = __importDefault(require("@supercharge/fs"));
class LoadEnvironmentVariables {
    /**
     * Create a new instance.
     *
     * @param app Application
     */
    constructor(app) {
        this.app = app;
    }
    /**
     * Boot application services.
     */
    async bootstrap() {
        await this.loadEnvironment();
    }
    /**
     * Load the contents of the configured environment file. Throws an error
     * in case the environment file does not exist, an error will be thrown.
     *
     * @throws
     */
    async loadEnvironment() {
        await this.ensureEnvironmentFileExists();
        dotenv_1.default.config({ path: this.environmentFile() });
    }
    /**
     * Throws if the environment file does not exists.
     *
     * @throws
     */
    async ensureEnvironmentFileExists() {
        if (await fs_1.default.notExists(this.environmentFile())) {
            throw new Error(`Invalid environment file. Cannot find env file "${this.environmentFile()}".`);
        }
    }
    /**
     * Returns the application’s environment file. By default: `.env`.
     */
    environmentFile() {
        return this.app.environmentFile();
    }
}
exports.LoadEnvironmentVariables = LoadEnvironmentVariables;
