import { Command, Application as Craft } from '@supercharge/console';
import { Application, BootstrapperCtor, ConsoleKernel as ConsoleKernelContract } from '@supercharge/contracts';
export declare class ConsoleKernel implements ConsoleKernelContract {
    private readonly meta;
    /**
     * Create a new console kernel instance.
     *
     * @param {Application} app
     */
    constructor(app: Application);
    /**
     * Returns the application instance.
     *
     * @returns {Application}
     */
    app(): Application;
    /**
     * Returns the list of application bootstrappers.
     */
    protected bootstrappers(): BootstrapperCtor[];
    /**
     * Handle an incoming console command for the given `input`.
     *
     * @param {Array} input - command line arguments (process.argv)
     *
     * @returns {Promise}
     */
    run(input?: string[]): Promise<any>;
    /**
     * Bootstrap the console application for Craft commands.
     */
    bootstrap(): Promise<void>;
    /**
     * Returns the list of command class names to exclude when loading all
     * commands into the console application. This is useful for base
     * commands that provide shared functionality to other commands.
     *
     * @returns {Array}
     */
    excludedCommands(): string[];
    /**
     * Register the console commands to the application.
     */
    commands(): Promise<void>;
    /**
     * Register all of the commands in the given `directories`.
     *
     * @param {Array} paths
     */
    loadFrom(...paths: string[]): Promise<void>;
    /**
     * Requires the given file from disk.
     *
     * @param {String} commandFile
     *
     * @returns {Command}
     */
    resolve(commandFile: string): Promise<Command>;
    /**
     * Determine whether the given `command` should not be excluded
     * from loading it to the list of available commands.
     *
     * @param {Command} command
     *
     * @returns {Boolean}
     */
    isNotExcluded(command: Command): boolean;
    /**
     * Determine whether the given `command` should be excluded
     * from loading it to the list of available commands.
     *
     * @param {Command} command
     *
     * @returns {Boolean}
     */
    shouldExclude(command: Command): boolean;
    /**
     * Returns a Craft console application instance.
     *
     * @returns {Craft}
     */
    craft(): Craft;
}
