import { HttpError } from './http-error';
import { Application, ErrorHandler as ErrorHandlerContract, HttpContext, Logger, ViewEngine } from '@supercharge/contracts';
export declare class ErrorHandler implements ErrorHandlerContract {
    /**
     * The application instance.
     */
    private readonly app;
    /**
     * Stores the list of report callbacks.
     */
    private readonly reportCallbacks;
    /**
     * Create a new error handler instance.
     */
    constructor(app: Application);
    /**
     * The application’s logger instance.
     */
    logger(): Logger;
    /**
     * The application’s view renderer.
     */
    view(): ViewEngine;
    /**
     * Register the error handling callbacks. For example, to report error
     * upstream to an error tracking service, like Sentry or Bugsnag.
     */
    register(): void;
    /**
     * Register a reportable callback.
     *
     * @param  {Function} reportUsing
     *
     * @returns {ErrorHandler}
     */
    reportable(reportUsing: (ctx: HttpContext, error: HttpError) => void | Promise<void>): ErrorHandler;
    /**
     * Returns the default logging context.
     *
     * @param {HttpContext} ctx
     *
     * @returns {*}
     */
    context(_ctx: HttpContext): any;
    /**
     * Handle the given error.
     *
     * @param {HttpContext} ctx
     * @param {Error} error
     */
    handle(ctx: HttpContext, error: Error): Promise<void>;
    /**
     * Report an error.
     *
     * @param {HttpContext} ctx
     * @param {HttpError} error
     */
    report(ctx: HttpContext, error: HttpError): Promise<void>;
    /**
     * Render the error into an HTTP response.
     *
     * @param {HttpContext} ctx
     * @param {HttpError} error
     */
    render(ctx: HttpContext, error: HttpError): Promise<any>;
    /**
     * Creates a JSON response depending on the app’s environment.
     *
     * @param {HttpContext} ctx
     * @param {HttpError} error
     */
    renderJsonResponse(ctx: HttpContext, error: HttpError): void;
    /**
     * Creates an HTML response depending on the app’s environment.
     *
     * @param {HttpContext} ctx
     * @param {HttpError} error
     */
    renderViewResponse(ctx: HttpContext, error: HttpError): Promise<void>;
    /**
     * Determine whether a view template file is missing for the given `error`.
     *
     * @param {HttpError} error
     *
     * @returns {Boolean}
     */
    private isMissingTemplateFor;
    /**
     * Determine whether a view template file exists for the given `error`.
     *
     * @param {HttpError} error
     *
     * @returns {Boolean}
     */
    private templateExistsFor;
    /**
     * Returns the view template file for the given `error`.
     *
     * @param {HttpError} error
     *
     * @returns {String}
     */
    private viewTemplateFor;
}
