'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.HttpError = void 0;
const errors_1 = require("@supercharge/errors");
class HttpError extends errors_1.HttpError {
    /**
     * Create a new HTTP error instance.
     *
     * @param {String} message
     */
    constructor(message) {
        super(message, 500);
    }
    /**
     * Returns a new HTTP error instance wrapping the given `error`.
     *
     * @param {Error} error
     *
     * @returns {HttpError}
     */
    static wrap(error) {
        return new HttpError(error.message).withStatus(this.retrieveStatusFrom(error));
    }
    /**
     * Retrieves an available status code from the error instance.
     * Falls back to HTTP status 500 if no status code is found.
     *
     * @param {Error} error
     *
     * @returns {Number}
     */
    static retrieveStatusFrom(error) {
        return error.status || error.statusCode || 500;
    }
}
exports.HttpError = HttpError;
