import { Application, BootstrapperCtor, HttpKernel as HttpKernelContract, MiddlewareCtor } from '@supercharge/contracts';
declare type Callback = () => unknown | Promise<unknown>;
export declare class HttpKernel implements HttpKernelContract {
    /**
     * Stores the HTTP kernel’s meta data.
     */
    private readonly meta;
    /**
     * The HTTP server instance.
     */
    private readonly server;
    /**
     * Create a new HTTP kernel instance.
     *
     * @param {Application} app
     */
    constructor(app: Application);
    /**
     * Creates a new HTTP kernel instance for the given `app`.
     *
     * @param {Application} app
     */
    static for(app: Application): HttpKernel;
    /**
     * Register the booting or booted callbacks. For example, you may use a `booted`
     * callback to send a "ready" signal to PM2 (or any other process manager)
     * informing that your HTTP server is ready to accept incoming requests.
     */
    register(): void;
    /**
     * Returns the application’s global middleware stack. Every middleware
     * listed here runs on every request to the application.
     *
     * @returns {MiddlewareCtor[]}
     */
    middleware(): MiddlewareCtor[];
    /**
     * Returns the application’s global middleware stack. Every middleware
     * listed here runs on every request to the application.
     *
     * @returns {MiddlewareCtor[]}
     */
    routeMiddleware(): {
        [key: string]: MiddlewareCtor;
    };
    /**
     * Returns the path to the HTTP controllers.
     *
     * @returns {String}
     */
    protected controllersLocation(): string;
    /**
     * Register a booted callback that runs after the HTTP server started.
     *
     * @returns {this}
     */
    booted(callback: Callback): this;
    /**
     * Returns the booted callbacks.
     *
     * @returns {Callback[]}
     */
    bootedCallbacks(): Callback[];
    /**
     * Returns the app instance.
     */
    app(): Application;
    /**
     * Start the HTTP instance listening for incoming requests.
     *
     * @returns {Promise}
     */
    startServer(): Promise<void>;
    /**
     * Bootstrap the application by loading environment variables, load the
     * configuration, register service providers into the IoC container
     * and ultimately boot the registered providers.
     */
    protected bootstrap(): Promise<void>;
    /**
     * Returns the list of application bootstrappers.
     */
    bootstrappers(): BootstrapperCtor[];
    /**
     * Returns an array of file paths to all controllers.
     *
     * @returns {String[]}
     */
    controllerPaths(): Promise<string[]>;
    /**
     * Start the HTTP server to listen on a local port.
     */
    protected listen(): Promise<void>;
    /**
     * Run the configured `booted` callbacks.
     */
    protected runBootedCallbacks(): Promise<void>;
    /**
     * Call the given kernal `callbacks`.
     *
     * @param {Callback[]} callbacks
     */
    protected runCallbacks(callbacks: Callback[]): Promise<void>;
}
export {};
