'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.RouteServiceProvider = void 0;
const goodies_1 = require("@supercharge/goodies");
const support_1 = require("@supercharge/support");
class RouteServiceProvider extends support_1.ServiceProvider {
    /**
     * Register application services to the container.
     */
    register() {
        this.booted(() => {
            this.loadRoutes();
        });
    }
    /**
     * Register a callback that will be used to load the application’s routes.
     *
     * @param callback
     *
     * @returns {RouteServiceProvider}
     */
    loadRoutesUsing(callback) {
        return (0, goodies_1.tap)(this, () => {
            this.loadRoutesCallback = callback;
        });
    }
    /**
     * Load the routes file from the given `path`.
     *
     * @param callback
     *
     * @returns {RouteServiceProvider}
     */
    loadRoutesFrom(path) {
        return (0, goodies_1.tap)(this, () => {
            require(path);
        });
    }
    /**
     * Load the application routes.
     *
     * @return void
     */
    loadRoutes() {
        if (typeof this.loadRoutesCallback === 'function') {
            return this.loadRoutesCallback();
        }
    }
}
exports.RouteServiceProvider = RouteServiceProvider;
